Overview — ETE Toolkit - analysis and visualization of trees

# ETE Toolkit - analysis and visualization of trees

Welcome! This is the documentation for ETE Toolkit 3.1.1, last updated Nov 03, 2017.

ETE is a Python programming toolkit that assists in the automated manipulation, analysis and visualization of phylogenetic trees. It provides a wide range of tree handling options, node annotation features and specialized features to deal with phylogenetic trees (i.e automatic orthology and paralogy detection, phylostratigraphy, tree reconciliation, etc). ETE implements also an interactive tree visualization system based on a a highly customizable tree drawing engine (PDF and SVG tree images). Although ETE is developed as a tool for phylogenetic analysis, it is also used to handle other types of hierarchical trees (i.e. clustering results).

Python API Tutorial Python API Reference Phylogenomic tools | Setup and Install Contributing

If you use ETE to analyze, process or visuallize results in a published work, please do not forget to support the project by citing:
Jaime Huerta-Cepas, Joaquín Dopazo and Toni Gabaldón. ETE: a python Environment for Tree Exploration. BMC Bioinformatics 2010, 11:24. doi:10.1186/1471-2105-11-24
Download this documentation as PDF.
More info and examples are available at http://etetoolkit.org